Learn R Programming

segregatr (version 0.5.0)

sFLB: 'Shared' full-likelihood Bayes factor

Description

Computes the shared Bayes factor for co-segregation, assuming autosomal dominant inheritance and a single introduction of the variant.

Usage

sFLB(
  x,
  carriers = NULL,
  noncarriers = NULL,
  affected = NULL,
  unknown = NULL,
  penetrances = NULL,
  liability = NULL,
  ...
)

Value

A positive number, the sFLB score.

Arguments

x

A pedtools::ped() object.

carriers

A character vector (or coercible to such), containing the ID labels of pedigree members known to carry one copy of the variant in question.

noncarriers

A character vector (or coercible to such), containing the ID labels of pedigree members known not to carry the variant in question.

affected

The affected pedigree members.

unknown

Pedigree members with unknown affection status.

penetrances

A numeric vector of length 3 (f0, f1, f2), or a matrix-like with 3 columns, where row i contains the penetrances of liability class i.

liability

A vector of length pedsize(x), containing for each pedigree member the row number of penetrances which should be used for that individual. If unnamed, it is assumed that the individuals are taken in order. (If penetrances is just a vector, it will be used for all classes.) If liability is NULL (the default), it is set to 1 for all individuals.

...

Further parameters.

References

Ratajska A, Vigeland MD, Wirgenes KV, et al. The use of segregation analysis in interpretation of sequence variants in SMAD3: A case report. Mol Genet Genomic Med, 2023. tools:::Rd_expr_doi("10.1002/mgg3.2107").

Examples

Run this code

### Case 1

x = halfSibPed(nch1 = 2, type = "maternal")

sFLB(x, unknown = 1:3, affected = 4:6, carriers = 4:6,
     noncarriers = NULL, penetrances = c(0.1, 0.5, 0.5))


### Ratajska et al. (2023), Family B

y = nuclearPed(5, sex = c(2,1,1,1,1)) |>
      addDaughter(parents = 3, verbose = FALSE) |>
      relabel("asPlot")

sFLB(y, unknown = NULL, affected = c(1,4,5,8), carriers = c(1,4,8),
     noncarriers = 6:7, penetrances = c(0.01, 0.9, 0.9))

Run the code above in your browser using DataLab