Learn R Programming

segregatr (version 0.5.0)

segregatr-package: segregatr: Segregation Analysis for Variant Interpretation

Description

An implementation of the full-likelihood Bayes factor (FLB) for evaluating segregation evidence in clinical medical genetics. The method was introduced by Thompson et al. (2003) tools:::Rd_expr_doi("10.1086/378100"). This implementation supports custom penetrance values and liability classes, and allows visualisations and robustness analysis as presented in Ratajska et al. (2023) tools:::Rd_expr_doi("10.1002/mgg3.2107"). See also the online app 'shinyseg', https://chrcarrizosa.shinyapps.io/shinyseg, which offers interactive segregation analysis with many additional features (Carrizosa et al. (2024) tools:::Rd_expr_doi("10.1093/bioinformatics/btae201")).

Arguments

Author

Maintainer: Magnus Dehli Vigeland m.d.vigeland@medisin.uio.no (ORCID)

Authors:

  • Christian Carrizosa (ORCID)

See Also